==> transport-energy-2020.11.13.tar.gz: transport-energy-2020.11.13/README.md <==
Tools for the iTEM databases
============================

[![Build Status](https://travis-ci.org/transportenergy/database.svg?branch=master)](https://travis-ci.org/transportenergy/database)
![Codecov](https://img.shields.io/codecov/c/gh/transportenergy/database.svg)
[![Documentation Status](https://readthedocs.org/projects/transportenergy/badge/?version=latest)](https://transportenergy.readthedocs.io/en/latest/?badge=latest)

This repository contains tools for two databases maintained by [iTEM](https://transportenergy.org), the **International Transport Energy Modeling** consortium:

1. A *historical database* to form a common, public, “best available” baseline for model calibration and projections.
   The historical database is under continuous development.

2. A *model database* of transport energy projections assembled as part of the iTEM model intercomparison projects (MIPs) linked to [iTEM workshops](https://transportenergy.org/workshops/).
   To meet the intellectual property concerns of workshop participants, the model database is currently not public, and only available on request; however, the tools used to prepare it are public.
   These tools are developed periodically, during sequential MIPs.

For details on installation, usage, contributing, etc., see the **online documentation** at https://transportenergy.readthedocs.io, automatically built from the contents of this repository.

License
-------

Copyright © 2017–2020, [iTEM contributors](https://github.com/transportenergy/database/graphs/contributors)

Licensed under the GNU General Public License, version 3.
The full text of the license is available in the file `LICENSE`.

See the online documentation for [citation of this software](https://transportenergy.readthedocs.io) in scientific publications that use the software *or* the resulting database.

Related repositories
--------------------

- [transportenergy/item_mip_data_processing](https://github.com/transportenergy/item_mip_data_processing): tools for iTEM MIP3.
- [transportenergy/metadata](https://github.com/transportenergy/metadata): shared metadata about models and historical data sources.

==> transport-energy-2021.5.4.tar.gz: transport-energy-2021.5.4/README.md <==
Tools for the iTEM databases
============================

[![Build Status](https://travis-ci.org/transportenergy/database.svg?branch=master)](https://travis-ci.org/transportenergy/database)
![Codecov](https://img.shields.io/codecov/c/gh/transportenergy/database.svg)
[![Documentation Status](https://readthedocs.org/projects/transportenergy/badge/?version=latest)](https://transportenergy.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4271789.svg)](https://doi.org/10.5281/zenodo.4271789)


This repository contains tools for two databases maintained by [iTEM](https://transportenergy.org), the **International Transport Energy Modeling** consortium:

1. A *historical database* to form a common, public, “best available” baseline for model calibration and projections.
   The historical database is under continuous development.

2. A *model database* of transport energy projections assembled as part of the iTEM model intercomparison projects (MIPs) linked to [iTEM workshops](https://transportenergy.org/workshops/).
   To meet the intellectual property concerns of workshop participants, the model database is currently not public, and only available on request; however, the tools used to prepare it are public.
   These tools are developed periodically, during sequential MIPs.

For details on installation, usage, contributing, etc., see the **online documentation** at https://transportenergy.readthedocs.io, automatically built from the contents of this repository.

License
-------

Copyright © 2017–2021, [iTEM contributors](https://github.com/transportenergy/database/graphs/contributors)

Licensed under the GNU General Public License, version 3.
The full text of the license is available in the file `LICENSE`.

See the online documentation for [citation of this software](https://transportenergy.readthedocs.io/#citation) in scientific publications that use the software *or* the resulting database.

Related repositories
--------------------

- [transportenergy/item_mip_data_processing](https://github.com/transportenergy/item_mip_data_processing): tools for iTEM MIP3.
- [transportenergy/metadata](https://github.com/transportenergy/metadata): shared metadata about models and historical data sources.
